@@ -275,7 +275,8 @@ def main():
 
     logFormatter = logging.Formatter('%(asctime)s %(name)s %(levelname)s: %(message)s')
 
-    fileHandler = logging.FileHandler("millconnect-client.log", mode='w')
+    logPath = QDir.home()
+    fileHandler = logging.FileHandler(logPath.filePath("millconnect-client.log"), mode='w')
     fileHandler.setFormatter(logFormatter)
 
     consoleHandler = logging.StreamHandler()
