@@ -224,8 +224,8 @@ class Project(object):
                     'id': None,
                     'fdi': tooth['fdi'],
                     'type': tooth['type'],
-                    'implant_type': tooth['implant_type'],
-                    'implant_system': tooth['implant_system']
+                    'implant_type': tooth['implant_type'] if 'implant_type' in tooth else None,
+                    'implant_system': tooth['implant_system'] if 'implant_system' in tooth else None
                 })
         
         self.order = order
